Iteration
---------

One of the things computers are often used for is the automation of
repetitive tasks. Repeating identical or similar tasks without making
errors is something that computers do well and people do poorly.

.. index::
   single: iteration 

We have seen programs that use recursion to perform repetition, such as
``nLines`` and ``countdown``. This type of repetition is called
**iteration**, and C++ provides several language features that make it
easier to write iterative programs.

The two features we are going to look at are the ``while`` statement and
the ``for`` statement.
